@@ -132,49 +132,93 @@ const char *rsp_c2_vreg_element_names[] = {
 /* Operands description */
 #define OPNDS_NONE 0,
 #define OPNDS_TARGET \
-	1, { TARGET_DECODER }
+	1, { \
+		TARGET_DECODER \
+	}
 #define OPNDS_RS_OFFSET \
-	2, { RS_DECODER, OFFSET_DECODER }
+	2, { \
+		RS_DECODER, OFFSET_DECODER \
+	}
 #define OPNDS_RS_RT_OFFSET \
-	3, { RS_DECODER, RT_DECODER, OFFSET_DECODER }
+	3, { \
+		RS_DECODER, RT_DECODER, OFFSET_DECODER \
+	}
 #define OPNDS_RT_BASE_OFFSET \
-	2, { RT_DECODER, BASE_OFFSET_DECODER }
+	2, { \
+		RT_DECODER, BASE_OFFSET_DECODER \
+	}
 #define OPNDS_RS \
-	1, { RS_DECODER }
+	1, { \
+		RS_DECODER \
+	}
 #define OPNDS_RT_LUI \
-	2, { RT_DECODER, LUI_DECODER }
+	2, { \
+		RT_DECODER, LUI_DECODER \
+	}
 #define OPNDS_RT_RS_SIMM \
-	3, { RT_DECODER, RS_DECODER, SIMM_DECODER }
+	3, { \
+		RT_DECODER, RS_DECODER, SIMM_DECODER \
+	}
 #define OPNDS_RT_RS_ZIMM \
-	3, { RT_DECODER, RS_DECODER, ZIMM_DECODER }
+	3, { \
+		RT_DECODER, RS_DECODER, ZIMM_DECODER \
+	}
 #define OPNDS_RD_RT_SA \
-	3, { RD_DECODER, RT_DECODER, SA_DECODER }
+	3, { \
+		RD_DECODER, RT_DECODER, SA_DECODER \
+	}
 #define OPNDS_RD_RT_RS \
-	3, { RD_DECODER, RT_DECODER, RS_DECODER }
+	3, { \
+		RD_DECODER, RT_DECODER, RS_DECODER \
+	}
 #define OPNDS_RD_RS_RT \
-	3, { RD_DECODER, RS_DECODER, RT_DECODER }
+	3, { \
+		RD_DECODER, RS_DECODER, RT_DECODER \
+	}
 #define OPNDS_RT_C0_REG \
-	2, { RT_DECODER, C0_REG_DECODER }
+	2, { \
+		RT_DECODER, C0_REG_DECODER \
+	}
 #define OPNDS_RT_C2_CREG \
-	2, { RT_DECODER, C2_CREG_DECODER }
+	2, { \
+		RT_DECODER, C2_CREG_DECODER \
+	}
 #define OPNDS_RT_VSB \
-	2, { RT_DECODER, VS_BYTE_DECODER }
+	2, { \
+		RT_DECODER, VS_BYTE_DECODER \
+	}
 #define OPNDS_VDS_VTS \
-	2, { VD_SCALAR_DECODER, VT_SCALAR_DECODER }
+	2, { \
+		VD_SCALAR_DECODER, VT_SCALAR_DECODER \
+	}
 #define OPNDS_VTB_BASE_OFFSET1 \
-	2, { VT_BYTE_DECODER, BASE_VOFFSET1_DECODER }
+	2, { \
+		VT_BYTE_DECODER, BASE_VOFFSET1_DECODER \
+	}
 #define OPNDS_VTB_BASE_OFFSET2 \
-	2, { VT_BYTE_DECODER, BASE_VOFFSET2_DECODER }
+	2, { \
+		VT_BYTE_DECODER, BASE_VOFFSET2_DECODER \
+	}
 #define OPNDS_VTB_BASE_OFFSET4 \
-	2, { VT_BYTE_DECODER, BASE_VOFFSET4_DECODER }
+	2, { \
+		VT_BYTE_DECODER, BASE_VOFFSET4_DECODER \
+	}
 #define OPNDS_VTB_BASE_OFFSET8 \
-	2, { VT_BYTE_DECODER, BASE_VOFFSET8_DECODER }
+	2, { \
+		VT_BYTE_DECODER, BASE_VOFFSET8_DECODER \
+	}
 #define OPNDS_VTB_BASE_OFFSET16 \
-	2, { VT_BYTE_DECODER, BASE_VOFFSET16_DECODER }
+	2, { \
+		VT_BYTE_DECODER, BASE_VOFFSET16_DECODER \
+	}
 #define OPNDS_VD_VS_C2_ACCU \
-	3, { VD_DECODER, VS_DECODER, C2_ACCU_DECODER }
+	3, { \
+		VD_DECODER, VS_DECODER, C2_ACCU_DECODER \
+	}
 #define OPNDS_VD_VS_VTE \
-	3, { VD_DECODER, VS_DECODER, VT_ELEMENT_DECODER }
+	3, { \
+		VD_DECODER, VS_DECODER, VT_ELEMENT_DECODER \
+	}
 
 /* Instructions description */
 #define INVALID \
@@ -428,8 +472,8 @@ typedef struct {
 
 static const rsp_instruction_priv rsp_op_table[] = {
 	/* SPECIAL opcodes table
- * 0-63
- */
+	 * 0-63
+	 */
 	SLL, INVALID, SRL, SRA, SLLV, INVALID, SRLV, SRAV,
 	JR, INVALID, INVALID, INVALID, INVALID, BREAK, INVALID, INVALID,
 	INVALID, INVALID, INVALID, INVALID, INVALID, INVALID, INVALID, INVALID,
@@ -439,29 +483,29 @@ static const rsp_instruction_priv rsp_op_table[] = {
 	INVALID, INVALID, INVALID, INVALID, INVALID, INVALID, INVALID, INVALID,
 	INVALID, INVALID, INVALID, INVALID, INVALID, INVALID, INVALID, INVALID,
 	/* REGIMM opcodes table
-* 64-95
-*/
+	 * 64-95
+	 */
 	BLTZ, BGEZ, INVALID, INVALID, INVALID, INVALID, INVALID, INVALID,
 	INVALID, INVALID, INVALID, INVALID, INVALID, INVALID, INVALID, INVALID,
 	BLTZAL, BGEZAL, INVALID, INVALID, INVALID, INVALID, INVALID, INVALID,
 	INVALID, INVALID, INVALID, INVALID, INVALID, INVALID, INVALID, INVALID,
 	/* COP0 opcodes table
-* 96-127
-*/
+	 * 96-127
+	 */
 	MFC0, INVALID, INVALID, INVALID, MTC0, INVALID, INVALID, INVALID,
 	INVALID, INVALID, INVALID, INVALID, INVALID, INVALID, INVALID, INVALID,
 	INVALID, INVALID, INVALID, INVALID, INVALID, INVALID, INVALID, INVALID,
 	INVALID, INVALID, INVALID, INVALID, INVALID, INVALID, INVALID, INVALID,
 	/* COP2/1 opcodes table
-* 128-159
-*/
+	 * 128-159
+	 */
 	MFC2, INVALID, CFC2, INVALID, MTC2, INVALID, CTC2, INVALID,
 	INVALID, INVALID, INVALID, INVALID, INVALID, INVALID, INVALID, INVALID,
 	INVALID, INVALID, INVALID, INVALID, INVALID, INVALID, INVALID, INVALID,
 	INVALID, INVALID, INVALID, INVALID, INVALID, INVALID, INVALID, INVALID,
 	/* COP2/2 opcodes table
-* 160-223
-*/
+	 * 160-223
+	 */
 	VMULF, VMULU, INVALID, INVALID, VMUDL, VMUDM, VMUDN, VMUDH,
 	VMACF, VMACU, INVALID, INVALID, VMADL, VMADM, VMADN, VMADH,
 	VADD, VSUB, INVALID, VABS, VADDC, VSUBC, INVALID, INVALID,
@@ -471,22 +515,22 @@ static const rsp_instruction_priv rsp_op_table[] = {
 	VRCP, VRCPL, VRCPH, VMOV, VRSQ, VRSQL, VRSQH, VNOP,
 	INVALID, INVALID, INVALID, INVALID, INVALID, INVALID, INVALID, INVALID,
 	/* LWC2 opcodes table
-* 224-255
-*/
+	 * 224-255
+	 */
 	LBV, LSV, LLV, LDV, LQV, LRV, LPV, LUV,
 	LHV, LFV, INVALID, LTV, INVALID, INVALID, INVALID, INVALID,
 	INVALID, INVALID, INVALID, INVALID, INVALID, INVALID, INVALID, INVALID,
 	INVALID, INVALID, INVALID, INVALID, INVALID, INVALID, INVALID, INVALID,
 	/* SWC2 opcodes table
-* 256-287
-*/
+	 * 256-287
+	 */
 	SBV, SSV, SLV, SDV, SQV, SRV, SPV, SUV,
 	SHV, SFV, SWV, STV, INVALID, INVALID, INVALID, INVALID,
 	INVALID, INVALID, INVALID, INVALID, INVALID, INVALID, INVALID, INVALID,
 	INVALID, INVALID, INVALID, INVALID, INVALID, INVALID, INVALID, INVALID,
 	/* Main opcodes table
-* 288-351
-*/
+	 * 288-351
+	 */
 	INVALID, INVALID, J, JAL, BEQ, BNE, BLEZ, BGTZ,
 	ADDI, ADDIU, SLTI, SLTIU, ANDI, ORI, XORI, LUI,
 	INVALID, INVALID, INVALID, INVALID, INVALID, INVALID, INVALID, INVALID,
@@ -496,8 +540,8 @@ static const rsp_instruction_priv rsp_op_table[] = {
 	INVALID, INVALID, INVALID, INVALID, INVALID, INVALID, INVALID, INVALID,
 	INVALID, INVALID, INVALID, INVALID, INVALID, INVALID, INVALID, INVALID,
 	/* Pseudo opcodes
-* 352 - ???
-*/
+	 * 352 - ???
+	 */
 	NOP
 };
 
@@ -557,8 +601,8 @@ static const rsp_instruction_priv *rsp_decode_priv(ut32 iw) {
 
 static inline st32 rsp_sign_extend(st32 x, st32 m) {
 	/* assume that bits of x above the m are already zeros
-	* which is the case when called from rsp_operand_decode
-	*/
+	 * which is the case when called from rsp_operand_decode
+	 */
 	return (x ^ m) - m;
 }
 
