@@ -78,16 +78,16 @@ typedef struct pyc_context {
 	struct pyc_version version;
 	/* used from marshall.c */
 	RzList /*<char *>*/ *interned_table;
-	RzList /*<RzBinSection *>*/ *sections_cache;
-	RzList /*<RzBinString *>*/ *strings_cache;
-	RzList /*<RzBinSymbol *>*/ *symbols_cache;
+	RzPVector /*<RzBinSection *>*/ *sections_cache;
+	RzPVector /*<RzBinString *>*/ *strings_cache;
+	RzPVector /*<RzBinSymbol *>*/ *symbols_cache;
 	RzList /*<RzList<void *> *>*/ *shared;
 	RzList /*<pyc_object *>*/ *refs; // If you don't have a good reason, do not change this. And also checkout !refs in get_code_object()
 	ut32 magic_int;
 	ut32 symbols_ordinal;
 } RzBinPycObj;
 
-bool get_sections_symbols_from_code_objects(RzBinPycObj *pyc, RzBuffer *buffer, RzList /*<RzBinSection *>*/ *sections, RzList /*<RzBinSymbol *>*/ *symbols, RzList /*<pyc_code_object *>*/ *objs, ut32 magic);
+bool get_sections_symbols_from_code_objects(RzBinPycObj *pyc, RzBuffer *buffer, RzPVector /*<RzBinSection *>*/ *sections, RzPVector /*<RzBinSymbol *>*/ *symbols, RzList /*<pyc_code_object *>*/ *objs, ut32 magic);
 ut64 get_code_object_addr(RzBinPycObj *pyc, RzBuffer *buffer, ut32 magic);
 
 #endif
